
### Pymol Script for
### Aster Proteins Facilitate Nonvesicular Plasma Membrane to ER Cholesterol 
### Transport in Mammalian Cells.
### Sandhu, J. et al
### (2018) Cell 175: 514-529.e20
### DOI: 10.1016/j.cell.2018.08.033

### by Loren Williams
### Georgia Tech

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 2

fetch 6GQF, protein1
remove not chain A and protein1

create protein2, protein1
create protein3, protein1

hide everything, protein1
show cartoon, protein1
color red, ss h and protein1
color yellow, ss s and protein1
color green, ss l+'' and protein1

hide everything, protein2
show sticks, protein2
color red, name O* and protein2
color wheat, name C* and protein2
color blue, name N* and protein2
color yellow, name P* and protein2
color yellow, name S* and protein2

create cholesterol1, resn HC3
hide everything, cholesterol1
show spheres, cholesterol1
color red, name O* and cholesterol1
color magenta, name C* and cholesterol1
color blue, name N* and cholesterol1
color yellow, name P* and cholesterol1
color yellow, name S* and cholesterol1

create cholesterol2, cholesterol1
hide everything, cholesterol2
show sticks, cholesterol2
h_add cholesterol2

create pocket1, byres(protein1 within 4 of cholesterol1)
remove (pocket1 within .1 of cholesterol1)
color red, name O* and pocket1
color palecyan, name C* and pocket1
color blue, name N* and pocket1
color yellow, name P* and pocket1
color yellow, name S* and pocket1
hide everything, pocket1
show spheres, pocket1

create pocket2, pocket1
hide everything, pocket2
show sticks, pocket2
h_add pocket2

color wheat, protein3
color orange, (resn ala+gly+val+ile+leu+phe+met+cys) and protein3
color blue, (resn arg+lys) and protein3
color magenta, (resn asp+glu) and protein3
hide everything, protein3
show surface, protein3

create loop, resi 430-439 and protein2

disable all
enable protein1
enable cholesterol2

set_view (\
     0.101017930,    0.279824555,    0.954720497,\
    -0.989040971,   -0.075578414,    0.126799092,\
     0.107635491,   -0.957063317,    0.269123256,\
    -0.000048988,    0.000279330, -177.254531860,\
     0.394242287,    1.927564859,   17.305322647,\
  -193.505828857,  548.000061035,  -20.000000000 )





